public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
* [PATCH i-g-t v2 0/2] Use lowest mode for crc subtest
@ 2026-03-17  5:30 Santhosh Reddy Guddati
  2026-03-17  5:30 ` [PATCH i-g-t v2 1/2] lib/igt_kms: Add lowclk and highclk modes Santhosh Reddy Guddati
                   ` (5 more replies)
  0 siblings, 6 replies; 10+ messages in thread
From: Santhosh Reddy Guddati @ 2026-03-17  5:30 UTC (permalink / raw)
  To: igt-dev
  Cc: karthik.b.s, arun.r.murthy, ramanaidu.naladala,
	Santhosh Reddy Guddati

Introduce helpers to get lowest clk and highest clock modes.
Use low clock mode in async flip crc test.

Santhosh Reddy Guddati (2):
  lib/igt_kms: Add lowclk and highclk modes
  tests/kms_async_flips: Use lowest mode for crc subtest

 lib/igt_kms.c           | 36 ++++++++++++++++++++++++++++++++++++
 lib/igt_kms.h           |  2 ++
 tests/kms_async_flips.c |  5 +++--
 3 files changed, 41 insertions(+), 2 deletions(-)

-- 
2.34.1


^ permalink raw reply	[flat|nested] 10+ messages in thread
* [PATCH i-g-t v1] tests/kms_async_flips: Use lowest mode for crc subtest
@ 2026-03-09  8:24 Santhosh Reddy Guddati
  2026-03-17  4:56 ` [PATCH i-g-t v2 1/2] lib/igt_kms: Add lowclk and highclk modes Santhosh Reddy Guddati
  0 siblings, 1 reply; 10+ messages in thread
From: Santhosh Reddy Guddati @ 2026-03-09  8:24 UTC (permalink / raw)
  To: igt-dev; +Cc: karthik.b.s, arun.r.murthy, Santhosh Reddy Guddati

Currently The CRC subtest uses mode[0] which maps to preffered high
refresh mode. On panels with multiple modes, pick the lower mode to
speed up crc test.

Signed-off-by: Santhosh Reddy Guddati <santhosh.reddy.guddati@intel.com>
---
 tests/kms_async_flips.c | 15 +++++++++++++--
 1 file changed, 13 insertions(+), 2 deletions(-)

diff --git a/tests/kms_async_flips.c b/tests/kms_async_flips.c
index a42407363..8639e2299 100644
--- a/tests/kms_async_flips.c
+++ b/tests/kms_async_flips.c
@@ -825,6 +825,17 @@ static void paint_fb(data_t *data, struct igt_fb *fb,
 	}
 }
 
+static drmModeModeInfoPtr get_lower_mode_for_crc(igt_output_t *output)
+{
+	drmModeConnector *connector = output->config.connector;
+
+	igt_assert(connector->count_modes > 0);
+
+	igt_sort_connector_modes(connector, sort_drm_modes_by_clk_asc);
+
+	return &connector->modes[0];
+}
+
 static void test_crc(data_t *data)
 {
 	unsigned int frame = 0;
@@ -834,8 +845,8 @@ static void test_crc(data_t *data)
 
 	igt_display_commit2(&data->display, data->display.is_atomic ? COMMIT_ATOMIC : COMMIT_LEGACY);
 
-	/* make things faster by using a smallish mode */
-	mode = &data->output->config.connector->modes[0];
+	/* make things faster by using a lower bandwidth mode */
+	mode = get_lower_mode_for_crc(data->output);
 	width = mode->hdisplay;
 	height = mode->vdisplay;
 
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2026-03-24  9:19 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2026-03-17  5:30 [PATCH i-g-t v2 0/2] Use lowest mode for crc subtest Santhosh Reddy Guddati
2026-03-17  5:30 ` [PATCH i-g-t v2 1/2] lib/igt_kms: Add lowclk and highclk modes Santhosh Reddy Guddati
2026-03-24  9:18   ` Naladala, Ramanaidu
2026-03-17  5:30 ` [PATCH i-g-t v2 2/2] tests/kms_async_flips: Use lowest mode for crc subtest Santhosh Reddy Guddati
2026-03-24  9:11   ` Naladala, Ramanaidu
2026-03-17 14:37 ` ✓ Xe.CI.BAT: success for " Patchwork
2026-03-17 15:36 ` ✓ i915.CI.BAT: " Patchwork
2026-03-18 18:01 ` ✗ i915.CI.Full: failure " Patchwork
2026-03-18 23:01 ` ✗ Xe.CI.FULL: " Patchwork
  -- strict thread matches above, loose matches on Subject: below --
2026-03-09  8:24 [PATCH i-g-t v1] tests/kms_async_flips: " Santhosh Reddy Guddati
2026-03-17  4:56 ` [PATCH i-g-t v2 1/2] lib/igt_kms: Add lowclk and highclk modes Santhosh Reddy Guddati

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox